# https://search.opentofu.org/provider/ciscodevnet/meraki/latest

terraform {
  required_providers {
    meraki = {
      source = "ciscodevnet/meraki"
      version = "1.1.0"
    }
  }
}

provider "meraki" {}

data "meraki_organization" "TaintonInfrastructureCloud" {
  name = "Tainton Infrastructure Cloud"
}

data "meraki_network" "TaintonNet" {
  id              = "L_671599294431642401"
  organization_id = "537586"
  # name            = "TaintonNet"
}


resource "meraki_network" "TaintonNet" {
  organization_id = data.meraki_organization.TaintonInfrastructureCloud.id
  name            = data.meraki_network.TaintonNet.name
  product_types   = ["appliance", "camera", "switch", "wireless"]
  tags            = []
  time_zone       = "Europe/London"
  notes           = ""
}

resource "meraki_network_firmware_upgrades" "TaintonNet" {
  network_id = data.meraki_network.TaintonNet.id
  # products_appliance_next_upgrade_to_version_id             = "5149"
  products_appliance_participate_in_next_beta_release       = false
  # products_camera_next_upgrade_to_version_id                = null
  products_camera_participate_in_next_beta_release          = false
  # products_secure_connect_next_upgrade_to_version_id        = null
  products_secure_connect_participate_in_next_beta_release  = null
  # products_switch_next_upgrade_to_version_id                = null
  products_switch_participate_in_next_beta_release          = false
  # products_wireless_next_upgrade_to_version_id              = null
  products_wireless_participate_in_next_beta_release        = false
  timezone                                                  = "Europe/London"
  upgrade_window_day_of_week                                = "saturday"
  upgrade_window_hour_of_day                                = "4:00"
}

resource "meraki_network_alerts_settings" "TaintonNet" {
  network_id                            = data.meraki_network.TaintonNet.id
  muting_by_port_schedules_enabled      = false
  default_destinations_all_admins       = false
  default_destinations_snmp             = false
  default_destinations_emails           = ["luke@tainton.uk"]
  default_destinations_http_server_ids  = [
    "aHR0cHM6Ly9mbG93cy50YWludG9uLnVrL3dlYmhvb2stdGVzdC8xODgwMjlmMy1iYWVmLTQ1NzgtYWMzNy0yNWIzMjM5NTc3ZjM=",
    "aHR0cHM6Ly9mbG93cy50YWludG9uLnVrL3dlYmhvb2svMTg4MDI5ZjMtYmFlZi00NTc4LWFjMzctMjViMzIzOTU3N2Yz"
  ]
  alerts = [
    {
        type                               = "ampMalwareDetected"
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
    },
    {
        type                               = "ampMalwareBlocked"
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        filters_timeout                    = 5
        type                               = "applianceDown"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "failoverEvent"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "dhcpNoLeases"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "rogueAp"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "rogueDhcp"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "ipConflict"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "ip6Conflict"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "dhcp6naRenumber"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "dhcp6pdRenumber"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "cellularUpDown"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "clientConnectivity"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "vrrp"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "vpnConnectivityChange"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "settingsChanged"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        filters_period                     = 1200
        filters_threshold                  = 104857600
        type                               = "usageAlert"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "weeklyUmbrella"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "prefixStarvation"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        filters_timeout                    = 5
        type                               = "gatewayDown"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        type                               = "gatewayToRepeater"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        filters_timeout                    = 60
        type                               = "repeaterDown"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        filters_selector                   = jsonencode(
              {
                configs = [
                    {
                        duration  = 15
                        ssidNum   = 0
                        threshold = "low"
                    },
                            ]
                        }
                    )
        type                               = "snr"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        filters_selector                   = jsonencode(
              {
                configs = [
                    {
                        duration  = 120
                        ssidNum   = 0
                        threshold = "high"
                    },
                            ]
                        }
                    )
        type                               = "highWirelessUsage"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = true
        filters_selector                   = jsonencode(
              {
                configs                 = []
                eventReminderPeriodSecs = 10800
                smartEnabled            = true
                smartSensitivity        = "medium"
                        }
                    )
        type                               = "onboarding"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "weeklyPresence"
    },
    {
        alert_destinations_all_admins      = false
        alert_destinations_emails          = []
        alert_destinations_http_server_ids = []
        alert_destinations_snmp            = false
        enabled                            = false
        type                               = "uplinkIp6Conflict"
    },
  ]
}
